OiRA

# About

### What is the OiRA (Online Interactive Risk Assessment) project

Experience shows that proper risk assessment is the key to healthy workplaces. This is why EU-OSHA developed an easy-to-use and cost-free web application (the “OiRA” - Online interactive Risk Assessment) that can help micro and small organisations to put in place a step-by-step risk assessment process – starting with the identification and evaluation of workplace risks, through decision making on preventive actions and the taking of action, to monitoring and reporting.

The OiRA web application gives access to the sectoral Risk Assessment tools created and maintained by sectoral organisations at national level.

### Why the OiRA project

The European Community Strategy on Health and Safety at Work 2007-2012 calls for the development of simple tools to facilitate risk assessment. Since the adoption of the European Framework directive in 1989, risk assessment has become a familiar concept for organising prevention in the workplace, and hundreds of thousands of companies all over Europe assess their risks regularly. Nevertheless, there is sufficient evidence to conclude that micro and small enterprises have some shortcomings when it comes to risk assessment and the adoption of a preventive policy in general which the OiRA project aims to overcome.

More information about the OiRA project

## Project Phases

### Development and pilot phase – 2009-2011

After the technical development of the tool in 2009, in 2010 (until the first half of 2011) the Agency is piloting the development and diffusion model at both EU level (working with the Sectoral Social Dialogue Committees) and at Member State level (with several Member States) as part of the testing of the tool and the development of appropriate support and guidance services.

### Official launch of the project – September 2011

The official launch of the tool is planned for September 2011, once the objectives of the testing phase have been reached and once the OiRA website, the OiRA training scheme and OiRA help desk will be ready.

## Development partners

The OiRA project and its related web application has been developed by the EU-OSHA based on the Dutch RA-instrument (called RI&E), which, financed by the Dutch government, was initially developed by TNO in collaboration with the employers organisation for small and medium-sized enterprises MKB-Nederland and the Dutch Ministry for Employment. Further development of the application was realised with input and participation of trade unions FNV, CNV and MHP.

The following technical partners contributed to the development of the OiRA project:

- TNO / The Netherlands
- Simplon / The Netherlands
- Cornelis G.A. Kolbach / The Netherlands
- Syslabcom / Germany

The Agency was also given strategic and expert advice by a Steering Committee in the development and implementation of the OiRA project. Members and alternates of the Steering Committee were appointed by the interest groups at the Board, by the Commission and by EU-OSHA.

## Licenses

The source code of the OiRA application is GPL licensed.

The content of OiRA sectoral tools is licensed under a Creative Commons Attribution-ShareAlike 2.5 Generic License.

The OiRA sectoral tools can be used for free by all users.

Link to sector organisation | Disclaimer | About